API Reference
=================
This page hold mrQA's API documentation, which might be helpful for the
neuroimaging community. For the sake of brevity, we highlight the high level
API of mrQA. The high-level API would allow your to do the most common tasks.

The most important methods are ``mrQA.project.check_compliance``. Here is a
summarized reference of commonly used methods.

High level API
----------------
..
  mrQA.cli module
  ---------------

  .. automodule:: mrQA.cli
     :members:
     :undoc-members:
     :show-inheritance:

  mrQA.common module
  ------------------

  .. automodule:: mrQA.common
   :members:
   :undoc-members:
   :show-inheritance:

  mrQA.config module
  ------------------

  .. automodule:: mrQA.config
   :members:
   :undoc-members:
   :show-inheritance:

  mrQA.formatter module
  ---------------------

  .. automodule:: mrQA.formatter
   :members:
   :undoc-members:
   :show-inheritance:

mrQA.project module
-------------------

.. automodule:: mrQA.project
   :members:
   :undoc-members:
   :show-inheritance:

mrQA.utils module
-----------------

.. automodule:: mrQA.utils
   :members:
   :undoc-members:
   :show-inheritance:
..
  Module contents
  ---------------

.. automodule:: mrQA
   :members:
   :undoc-members:
   :show-inheritance:
